#include "mainwindow.h"
#include "ui_mainwindow.h"

#include <QDebug>
#include <QTimer>

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    // Timer for GMT main clock display.
    QTimer *timer = new QTimer(this);
    connect(timer, SIGNAL(timeout()), this, SLOT(up_to_date()));
    timer->start(100);   //Reference: 1000msec = 1 sec, 3600000 = 1 hour, 21600000 = 6 hours
    old_min = 99;
    old_sec = 99;
    ui->statusBar->showMessage("Wait up to 10 seconds for sync", 10000);
    load_web_page();
}

MainWindow::~MainWindow()
{
    delete ui;
}


void MainWindow::up_to_date()
{
    utc_dt = utc_dt.currentDateTimeUtc();
    utc = utc_dt.time();
    utc_time = utc.toString("HH:mm:ss");
    ui->gmt_LE->setText(utc_time);
    // Now break out only the minutes and seconds
    min = utc.minute();
    m = min; //Convert int to float
    sec = utc.second();
    s = sec; //Convert int to float
    // Account for program start up uncertainty
    if(old_min == 99){
        old_min = min;
    }
    if(old_sec == 99){
        old_sec = sec;
    }
// Not happy with this next part.  But it works.
    mm = ((m / 3) - (min / 3));
    if(mm < .2){
        my_min = 1;
    }
    if(mm > .3  && mm < .4){
        my_min = 2;
    }
    if(mm > .5){
        my_min = 3;
    }
// <shudder>Glad thats over

// See if minute has changed
    if(min != old_min){
        if (((m / 3) - (min / 3)) == 0){
            // The 3 minute cycle has restarted
            //qDebug() << "DEBUG: 3 min cycle restarted, " << utc_time ;
        }
        old_min = min;
    }
    // See if second has changed
        if(sec != old_sec){
            if (((s / 10) - (sec / 10)) == 0){
                // Reset the 10 second timer
                //qDebug() << "DEBUG: 10 seconds , " << utc_time << " My_min = " << my_min;
                ui->statusBar->clearMessage();
                switch(sec)
                {
                case 0:
                    switch(my_min){
                    case 1:
                        ui->PB_20_18->setIcon(QIcon());
                        ui->PB_20_01->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_17->setIcon(QIcon());
                        ui->PB_18_18->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_16->setIcon(QIcon());
                        ui->PB_15_17->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_15->setIcon(QIcon());
                        ui->PB_12_16->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_14->setIcon(QIcon());
                        ui->PB_10_15->setIcon(QIcon(":/images/greenLED"));
                        break;
                    case 2:
                        ui->PB_20_06->setIcon(QIcon());
                        ui->PB_20_07->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_05->setIcon(QIcon());
                        ui->PB_18_06->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_04->setIcon(QIcon());
                        ui->PB_15_05->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_03->setIcon(QIcon());
                        ui->PB_12_04->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_02->setIcon(QIcon());
                        ui->PB_10_03->setIcon(QIcon(":/images/greenLED"));
                        break;
                    case 3:
                        ui->PB_20_12->setIcon(QIcon());
                        ui->PB_20_13->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_11->setIcon(QIcon());
                        ui->PB_18_12->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_10->setIcon(QIcon());
                        ui->PB_15_11->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_09->setIcon(QIcon());
                        ui->PB_12_10->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_08->setIcon(QIcon());
                        ui->PB_10_09->setIcon(QIcon(":/images/greenLED"));
                        break;
                    }
                    break;
                case 10:
                    switch(my_min){
                    case 1:
                        ui->PB_20_01->setIcon(QIcon());
                        ui->PB_20_02->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_18->setIcon(QIcon());
                        ui->PB_18_01->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_17->setIcon(QIcon());
                        ui->PB_15_18->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_16->setIcon(QIcon());
                        ui->PB_12_17->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_15->setIcon(QIcon());
                        ui->PB_10_16->setIcon(QIcon(":/images/greenLED"));
                        break;
                    case 2:
                        ui->PB_20_07->setIcon(QIcon());
                        ui->PB_20_08->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_06->setIcon(QIcon());
                        ui->PB_18_07->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_05->setIcon(QIcon());
                        ui->PB_15_06->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_04->setIcon(QIcon());
                        ui->PB_12_05->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_03->setIcon(QIcon());
                        ui->PB_10_04->setIcon(QIcon(":/images/greenLED"));
                        break;
                    case 3:
                        ui->PB_20_13->setIcon(QIcon());
                        ui->PB_20_14->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_12->setIcon(QIcon());
                        ui->PB_18_13->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_11->setIcon(QIcon());
                        ui->PB_15_12->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_10->setIcon(QIcon());
                        ui->PB_12_11->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_09->setIcon(QIcon());
                        ui->PB_10_10->setIcon(QIcon(":/images/greenLED"));
                        break;
                    }
                    break;
                case 20:
                    switch(my_min){
                    case 1:
                        ui->PB_20_02->setIcon(QIcon());
                        ui->PB_20_03->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_01->setIcon(QIcon());
                        ui->PB_18_02->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_18->setIcon(QIcon());
                        ui->PB_15_01->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_17->setIcon(QIcon());
                        ui->PB_12_18->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_16->setIcon(QIcon());
                        ui->PB_10_17->setIcon(QIcon(":/images/greenLED"));
                        break;
                    case 2:
                        ui->PB_20_08->setIcon(QIcon());
                        ui->PB_20_09->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_07->setIcon(QIcon());
                        ui->PB_18_08->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_06->setIcon(QIcon());
                        ui->PB_15_07->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_05->setIcon(QIcon());
                        ui->PB_12_06->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_04->setIcon(QIcon());
                        ui->PB_10_05->setIcon(QIcon(":/images/greenLED"));
                        break;
                    case 3:
                        ui->PB_20_14->setIcon(QIcon());
                        ui->PB_20_15->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_13->setIcon(QIcon());
                        ui->PB_18_14->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_12->setIcon(QIcon());
                        ui->PB_15_13->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_11->setIcon(QIcon());
                        ui->PB_12_12->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_10->setIcon(QIcon());
                        ui->PB_10_11->setIcon(QIcon(":/images/greenLED"));
                        break;
                    }
                    break;
                case 30:
                    switch(my_min){
                    case 1:
                        ui->PB_20_03->setIcon(QIcon());
                        ui->PB_20_04->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_02->setIcon(QIcon());
                        ui->PB_18_03->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_01->setIcon(QIcon());
                        ui->PB_15_02->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_18->setIcon(QIcon());
                        ui->PB_12_01->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_17->setIcon(QIcon());
                        ui->PB_10_18->setIcon(QIcon(":/images/greenLED"));
                        break;
                    case 2:
                        ui->PB_20_09->setIcon(QIcon());
                        ui->PB_20_10->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_08->setIcon(QIcon());
                        ui->PB_18_09->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_07->setIcon(QIcon());
                        ui->PB_15_08->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_06->setIcon(QIcon());
                        ui->PB_12_07->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_05->setIcon(QIcon());
                        ui->PB_10_06->setIcon(QIcon(":/images/greenLED"));
                        break;
                    case 3:
                        ui->PB_20_15->setIcon(QIcon());
                        ui->PB_20_16->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_14->setIcon(QIcon());
                        ui->PB_18_15->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_13->setIcon(QIcon());
                        ui->PB_15_14->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_12->setIcon(QIcon());
                        ui->PB_12_13->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_11->setIcon(QIcon());
                        ui->PB_10_12->setIcon(QIcon(":/images/greenLED"));
                        break;
                    }
                    break;
                case 40:
                    switch(my_min){
                    case 1:
                        ui->PB_20_04->setIcon(QIcon());
                        ui->PB_20_05->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_03->setIcon(QIcon());
                        ui->PB_18_04->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_02->setIcon(QIcon());
                        ui->PB_15_03->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_01->setIcon(QIcon());
                        ui->PB_12_02->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_18->setIcon(QIcon());
                        ui->PB_10_01->setIcon(QIcon(":/images/greenLED"));
                        break;
                    case 2:
                        ui->PB_20_10->setIcon(QIcon());
                        ui->PB_20_11->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_09->setIcon(QIcon());
                        ui->PB_18_10->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_08->setIcon(QIcon());
                        ui->PB_15_09->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_07->setIcon(QIcon());
                        ui->PB_12_08->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_06->setIcon(QIcon());
                        ui->PB_10_07->setIcon(QIcon(":/images/greenLED"));
                        break;
                    case 3:
                        ui->PB_20_16->setIcon(QIcon());
                        ui->PB_20_17->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_15->setIcon(QIcon());
                        ui->PB_18_16->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_14->setIcon(QIcon());
                        ui->PB_15_15->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_13->setIcon(QIcon());
                        ui->PB_12_14->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_12->setIcon(QIcon());
                        ui->PB_10_13->setIcon(QIcon(":/images/greenLED"));
                        break;
                    }
                    break;
                case 50:
                    switch(my_min){
                    case 1:
                        ui->PB_20_05->setIcon(QIcon());
                        ui->PB_20_06->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_04->setIcon(QIcon());
                        ui->PB_18_05->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_03->setIcon(QIcon());
                        ui->PB_15_04->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_02->setIcon(QIcon());
                        ui->PB_12_03->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_01->setIcon(QIcon());
                        ui->PB_10_02->setIcon(QIcon(":/images/greenLED"));
                        break;
                    case 2:
                        ui->PB_20_11->setIcon(QIcon());
                        ui->PB_20_12->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_10->setIcon(QIcon());
                        ui->PB_18_11->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_09->setIcon(QIcon());
                        ui->PB_15_10->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_08->setIcon(QIcon());
                        ui->PB_12_09->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_07->setIcon(QIcon());
                        ui->PB_10_08->setIcon(QIcon(":/images/greenLED"));
                        break;
                    case 3:
                        ui->PB_20_17->setIcon(QIcon());
                        ui->PB_20_18->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_18_16->setIcon(QIcon());
                        ui->PB_18_17->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_15_15->setIcon(QIcon());
                        ui->PB_15_16->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_12_14->setIcon(QIcon());
                        ui->PB_12_15->setIcon(QIcon(":/images/greenLED"));
                        ui->PB_10_13->setIcon(QIcon());
                        ui->PB_10_14->setIcon(QIcon(":/images/greenLED"));
                        break;
                    }
                    break;
                }
            }
            old_sec = sec;
        }

}

void MainWindow::bcn_status(){
    on_checkBox_1_clicked();
    on_checkBox_2_clicked();
    on_checkBox_3_clicked();
    on_checkBox_4_clicked();
    on_checkBox_5_clicked();
    on_checkBox_6_clicked();
    on_checkBox_7_clicked();
    on_checkBox_8_clicked();
    on_checkBox_9_clicked();
    on_checkBox_10_clicked();
    on_checkBox_11_clicked();
    on_checkBox_12_clicked();
    on_checkBox_13_clicked();
    on_checkBox_14_clicked();
    on_checkBox_15_clicked();
    on_checkBox_16_clicked();
    on_checkBox_17_clicked();
    on_checkBox_18_clicked();
}

void MainWindow::on_checkBox_1_clicked()
{
    if(ui->checkBox_1->isChecked()){
        ui->PB_20_01->setDisabled(TRUE);
        ui->PB_18_01->setDisabled(TRUE);
        ui->PB_15_01->setDisabled(TRUE);
        ui->PB_12_01->setDisabled(TRUE);
        ui->PB_10_01->setDisabled(TRUE);
    }else{
        ui->PB_20_01->setDisabled(FALSE);
        ui->PB_18_01->setDisabled(FALSE);
        ui->PB_15_01->setDisabled(FALSE);
        ui->PB_12_01->setDisabled(FALSE);
        ui->PB_10_01->setDisabled(FALSE);
    }

}


void MainWindow::on_checkBox_2_clicked()
{
    if(ui->checkBox_2->isChecked()){
        ui->PB_20_02->setDisabled(TRUE);
        ui->PB_18_02->setDisabled(TRUE);
        ui->PB_15_02->setDisabled(TRUE);
        ui->PB_12_02->setDisabled(TRUE);
        ui->PB_10_02->setDisabled(TRUE);
    }else{
        ui->PB_20_02->setDisabled(FALSE);
        ui->PB_18_02->setDisabled(FALSE);
        ui->PB_15_02->setDisabled(FALSE);
        ui->PB_12_02->setDisabled(FALSE);
        ui->PB_10_02->setDisabled(FALSE);
    }
}

void MainWindow::on_checkBox_3_clicked()
{
    if(ui->checkBox_3->isChecked()){
        ui->PB_20_03->setDisabled(TRUE);
        ui->PB_18_03->setDisabled(TRUE);
        ui->PB_15_03->setDisabled(TRUE);
        ui->PB_12_03->setDisabled(TRUE);
        ui->PB_10_03->setDisabled(TRUE);
    }else{
        ui->PB_20_03->setDisabled(FALSE);
        ui->PB_18_03->setDisabled(FALSE);
        ui->PB_15_03->setDisabled(FALSE);
        ui->PB_12_03->setDisabled(FALSE);
        ui->PB_10_03->setDisabled(FALSE);
    }
}

void MainWindow::on_checkBox_4_clicked()
{
    if(ui->checkBox_4->isChecked()){
        ui->PB_20_04->setDisabled(TRUE);
        ui->PB_18_04->setDisabled(TRUE);
        ui->PB_15_04->setDisabled(TRUE);
        ui->PB_12_04->setDisabled(TRUE);
        ui->PB_10_04->setDisabled(TRUE);
    }else{
        ui->PB_20_04->setDisabled(FALSE);
        ui->PB_18_04->setDisabled(FALSE);
        ui->PB_15_04->setDisabled(FALSE);
        ui->PB_12_04->setDisabled(FALSE);
        ui->PB_10_04->setDisabled(FALSE);
    }
}

void MainWindow::on_checkBox_5_clicked()
{
    if(ui->checkBox_5->isChecked()){
        ui->PB_20_05->setDisabled(TRUE);
        ui->PB_18_05->setDisabled(TRUE);
        ui->PB_15_05->setDisabled(TRUE);
        ui->PB_12_05->setDisabled(TRUE);
        ui->PB_10_05->setDisabled(TRUE);
    }else{
        ui->PB_20_05->setDisabled(FALSE);
        ui->PB_18_05->setDisabled(FALSE);
        ui->PB_15_05->setDisabled(FALSE);
        ui->PB_12_05->setDisabled(FALSE);
        ui->PB_10_05->setDisabled(FALSE);
    }
}

void MainWindow::on_checkBox_6_clicked()
{
    if(ui->checkBox_6->isChecked()){
        ui->PB_20_06->setDisabled(TRUE);
        ui->PB_18_06->setDisabled(TRUE);
        ui->PB_15_06->setDisabled(TRUE);
        ui->PB_12_06->setDisabled(TRUE);
        ui->PB_10_06->setDisabled(TRUE);
    }else{
        ui->PB_20_06->setDisabled(FALSE);
        ui->PB_18_06->setDisabled(FALSE);
        ui->PB_15_06->setDisabled(FALSE);
        ui->PB_12_06->setDisabled(FALSE);
        ui->PB_10_06->setDisabled(FALSE);
    }
}

void MainWindow::on_checkBox_7_clicked()
{
    if(ui->checkBox_7->isChecked()){
        ui->PB_20_07->setDisabled(TRUE);
        ui->PB_18_07->setDisabled(TRUE);
        ui->PB_15_07->setDisabled(TRUE);
        ui->PB_12_07->setDisabled(TRUE);
        ui->PB_10_07->setDisabled(TRUE);
    }else{
        ui->PB_20_07->setDisabled(FALSE);
        ui->PB_18_07->setDisabled(FALSE);
        ui->PB_15_07->setDisabled(FALSE);
        ui->PB_12_07->setDisabled(FALSE);
        ui->PB_10_07->setDisabled(FALSE);
    }
}

void MainWindow::on_checkBox_8_clicked()
{
    if(ui->checkBox_8->isChecked()){
        ui->PB_20_08->setDisabled(TRUE);
        ui->PB_18_08->setDisabled(TRUE);
        ui->PB_15_08->setDisabled(TRUE);
        ui->PB_12_08->setDisabled(TRUE);
        ui->PB_10_08->setDisabled(TRUE);
    }else{
        ui->PB_20_08->setDisabled(FALSE);
        ui->PB_18_08->setDisabled(FALSE);
        ui->PB_15_08->setDisabled(FALSE);
        ui->PB_12_08->setDisabled(FALSE);
        ui->PB_10_08->setDisabled(FALSE);
    }
}

void MainWindow::on_checkBox_9_clicked()
{
    if(ui->checkBox_9->isChecked()){
        ui->PB_20_09->setDisabled(TRUE);
        ui->PB_18_09->setDisabled(TRUE);
        ui->PB_15_09->setDisabled(TRUE);
        ui->PB_12_09->setDisabled(TRUE);
        ui->PB_10_09->setDisabled(TRUE);
    }else{
        ui->PB_20_09->setDisabled(FALSE);
        ui->PB_18_09->setDisabled(FALSE);
        ui->PB_15_09->setDisabled(FALSE);
        ui->PB_12_09->setDisabled(FALSE);
        ui->PB_10_09->setDisabled(FALSE);
    }
}

void MainWindow::on_checkBox_10_clicked()
{
    if(ui->checkBox_10->isChecked()){
        ui->PB_20_10->setDisabled(TRUE);
        ui->PB_18_10->setDisabled(TRUE);
        ui->PB_15_10->setDisabled(TRUE);
        ui->PB_12_10->setDisabled(TRUE);
        ui->PB_10_10->setDisabled(TRUE);
    }else{
        ui->PB_20_10->setDisabled(FALSE);
        ui->PB_18_10->setDisabled(FALSE);
        ui->PB_15_10->setDisabled(FALSE);
        ui->PB_12_10->setDisabled(FALSE);
        ui->PB_10_10->setDisabled(FALSE);
    }
}

void MainWindow::on_checkBox_11_clicked()
{
    if(ui->checkBox_11->isChecked()){
        ui->PB_20_11->setDisabled(TRUE);
        ui->PB_18_11->setDisabled(TRUE);
        ui->PB_15_11->setDisabled(TRUE);
        ui->PB_12_11->setDisabled(TRUE);
        ui->PB_10_11->setDisabled(TRUE);
    }else{
        ui->PB_20_11->setDisabled(FALSE);
        ui->PB_18_11->setDisabled(FALSE);
        ui->PB_15_11->setDisabled(FALSE);
        ui->PB_12_11->setDisabled(FALSE);
        ui->PB_10_11->setDisabled(FALSE);
    }
}

void MainWindow::on_checkBox_12_clicked()
{
    if(ui->checkBox_12->isChecked()){
        ui->PB_20_12->setDisabled(TRUE);
        ui->PB_18_12->setDisabled(TRUE);
        ui->PB_15_12->setDisabled(TRUE);
        ui->PB_12_12->setDisabled(TRUE);
        ui->PB_10_12->setDisabled(TRUE);
    }else{
        ui->PB_20_12->setDisabled(FALSE);
        ui->PB_18_12->setDisabled(FALSE);
        ui->PB_15_12->setDisabled(FALSE);
        ui->PB_12_12->setDisabled(FALSE);
        ui->PB_10_12->setDisabled(FALSE);
    }
}

void MainWindow::on_checkBox_13_clicked()
{
    if(ui->checkBox_13->isChecked()){
        ui->PB_20_13->setDisabled(TRUE);
        ui->PB_18_13->setDisabled(TRUE);
        ui->PB_15_13->setDisabled(TRUE);
        ui->PB_12_13->setDisabled(TRUE);
        ui->PB_10_13->setDisabled(TRUE);
    }else{
        ui->PB_20_13->setDisabled(FALSE);
        ui->PB_18_13->setDisabled(FALSE);
        ui->PB_15_13->setDisabled(FALSE);
        ui->PB_12_13->setDisabled(FALSE);
        ui->PB_10_13->setDisabled(FALSE);
    }
}

void MainWindow::on_checkBox_14_clicked()
{
    if(ui->checkBox_14->isChecked()){
        ui->PB_20_14->setDisabled(TRUE);
        ui->PB_18_14->setDisabled(TRUE);
        ui->PB_15_14->setDisabled(TRUE);
        ui->PB_12_14->setDisabled(TRUE);
        ui->PB_10_14->setDisabled(TRUE);
    }else{
        ui->PB_20_14->setDisabled(FALSE);
        ui->PB_18_14->setDisabled(FALSE);
        ui->PB_15_14->setDisabled(FALSE);
        ui->PB_12_14->setDisabled(FALSE);
        ui->PB_10_14->setDisabled(FALSE);
    }
}

void MainWindow::on_checkBox_15_clicked()
{
    if(ui->checkBox_15->isChecked()){
        ui->PB_20_15->setDisabled(TRUE);
        ui->PB_18_15->setDisabled(TRUE);
        ui->PB_15_15->setDisabled(TRUE);
        ui->PB_12_15->setDisabled(TRUE);
        ui->PB_10_15->setDisabled(TRUE);
    }else{
        ui->PB_20_15->setDisabled(FALSE);
        ui->PB_18_15->setDisabled(FALSE);
        ui->PB_15_15->setDisabled(FALSE);
        ui->PB_12_15->setDisabled(FALSE);
        ui->PB_10_15->setDisabled(FALSE);
    }
}

void MainWindow::on_checkBox_16_clicked()
{
    if(ui->checkBox_16->isChecked()){
        ui->PB_20_16->setDisabled(TRUE);
        ui->PB_18_16->setDisabled(TRUE);
        ui->PB_15_16->setDisabled(TRUE);
        ui->PB_12_16->setDisabled(TRUE);
        ui->PB_10_16->setDisabled(TRUE);
    }else{
        ui->PB_20_16->setDisabled(FALSE);
        ui->PB_18_16->setDisabled(FALSE);
        ui->PB_15_16->setDisabled(FALSE);
        ui->PB_12_16->setDisabled(FALSE);
        ui->PB_10_16->setDisabled(FALSE);
    }
}

void MainWindow::on_checkBox_17_clicked()
{
    if(ui->checkBox_17->isChecked()){
        ui->PB_20_17->setDisabled(TRUE);
        ui->PB_18_17->setDisabled(TRUE);
        ui->PB_15_17->setDisabled(TRUE);
        ui->PB_12_17->setDisabled(TRUE);
        ui->PB_10_17->setDisabled(TRUE);
    }else{
        ui->PB_20_17->setDisabled(FALSE);
        ui->PB_18_17->setDisabled(FALSE);
        ui->PB_15_17->setDisabled(FALSE);
        ui->PB_12_17->setDisabled(FALSE);
        ui->PB_10_17->setDisabled(FALSE);
    }
}

void MainWindow::on_checkBox_18_clicked()
{
    if(ui->checkBox_18->isChecked()){
        ui->PB_20_18->setDisabled(TRUE);
        ui->PB_18_18->setDisabled(TRUE);
        ui->PB_15_18->setDisabled(TRUE);
        ui->PB_12_18->setDisabled(TRUE);
        ui->PB_10_18->setDisabled(TRUE);
    }else{
        ui->PB_20_18->setDisabled(FALSE);
        ui->PB_18_18->setDisabled(FALSE);
        ui->PB_15_18->setDisabled(FALSE);
        ui->PB_12_18->setDisabled(FALSE);
        ui->PB_10_18->setDisabled(FALSE);
    }
}

void MainWindow::parse_web_page(){
//qDebug() << "DEBUG: Parsing Web page data";
    idata = &page;
    iframe =idata->mainFrame(); // Grabs the main frame from the web page so individual elements can be searched for.
   document = iframe->documentElement(); // Creates QWebElement from the frame.
   collection = document.findAll("table");  // All tables in the web page
   //qDebug() << "Tables found = " << collection.count() << "\n";
   table2 = collection.operator [](2);
   //qDebug() << "Table #2 = " << table2.toPlainText() << endl;
   table2_data = table2.firstChild();
   tr_collection = table2_data.findAll("tr");  // All tr's in the table
   //qDebug() << "Number of TR's in TABLE2 = " << tr_collection.count() << endl; // 20 TR's
   //Put loop here to check each Beacon Station Status
   int i;
   for(i = 2; i<=19; i++){
        tr_data = tr_collection.operator [](i);  // Location of first Beacon Station
        td_collection = tr_data.findAll("td");  // All td's in the tr
        //qDebug() << "Number of TD's in the TR = " << td_collection.count() << endl; //  10 TD's
         td_data = td_collection.operator [](9);  // Status of the Beacon Station
         //qDebug() << "TD = " << td_data.toPlainText() << endl;
        td_raw = td_data.toPlainText();
        if(td_raw.contains("OFF", Qt::CaseInsensitive)){
            //qDebug() << "Beacon off" << i;
            switch(i){
            case 2:
                ui->checkBox_1->setChecked(TRUE);
                break;
            case 3:
                ui->checkBox_2->setChecked(TRUE);
                break;
            case 4:
                ui->checkBox_3->setChecked(TRUE);
                break;
            case 5:
                ui->checkBox_4->setChecked(TRUE);
                break;
            case 6:
                ui->checkBox_5->setChecked(TRUE);
                break;
            case 7:
                ui->checkBox_6->setChecked(TRUE);
                break;
            case 8:
                ui->checkBox_7->setChecked(TRUE);
                break;
            case 9:
                ui->checkBox_8->setChecked(TRUE);
                break;
            case 10:
                ui->checkBox_9->setChecked(TRUE);
                break;
            case 11:
                ui->checkBox_10->setChecked(TRUE);
                break;
            case 12:
                ui->checkBox_11->setChecked(TRUE);
                break;
            case 13:
                ui->checkBox_12->setChecked(TRUE);
                break;
            case 14:
                ui->checkBox_13->setChecked(TRUE);
                break;
            case 15:
                ui->checkBox_14->setChecked(TRUE);
                break;
            case 16:
                ui->checkBox_15->setChecked(TRUE);
                break;
            case 17:
                ui->checkBox_16->setChecked(TRUE);
                break;
            case 18:
                ui->checkBox_17->setChecked(TRUE);
                break;
            case 19:
                ui->checkBox_18->setChecked(TRUE);
                break;
            }
        }

    }
bcn_status();
}

void MainWindow::load_web_page(){
    page.mainFrame()->load(QUrl("http://ncdxf.org/beacon/beaconschedule.html"));
         connect(&page, SIGNAL(loadFinished(bool)),
             this, SLOT(parse_web_page()));

}
